@@ -187,6 +187,8 @@ namespace Lum {
       friend LUMAPI bool operator!=(const SystemTime& a, const SystemTime& b);
       friend LUMAPI bool operator>=(const SystemTime& a, const SystemTime& b);
       friend LUMAPI bool operator>(const SystemTime& a, const SystemTime& b);
+
+      friend LUMAPI time_t operator-(const SystemTime& a, const SystemTime& b);
     };
 
     extern LUMAPI bool operator<(const SystemTime& a, const SystemTime& b);
@@ -196,6 +198,8 @@ namespace Lum {
     extern LUMAPI bool operator>=(const SystemTime& a, const SystemTime& b);
     extern LUMAPI bool operator>(const SystemTime& a, const SystemTime& b);
 
+    extern LUMAPI time_t operator-(const SystemTime& a, const SystemTime& b);
+
     /**
       simple mid resolution timer based on SystemTime.
     */
