@@ -47,6 +47,8 @@ namespace Lum {
     Base::Calendar     local;
     Model::CalendarRef model;
     size_t             weekStart;
+    size_t             topWidth;
+    size_t             topHeight;
     size_t             area[7][7];
     Text               *texts[31+7];
     Text               *current;
