@@ -20,8 +20,6 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/DatePicker.h>
-#include <Lum/Popup.h>
 #include <Lum/PopupControl.h>
 
 namespace Lum {
@@ -29,25 +27,6 @@ namespace Lum {
   */
   class LUMAPI DateSelect : public PopupControl
   {
-  private:
-    class DateSelectPopup : public Popup
-    {
-    public:
-      DateSelect *select;
-      DatePicker *picker;
-
-    public:
-      DateSelectPopup(DateSelect *combo);
-      ~DateSelectPopup();
-
-      void PreInit();
-
-      void Resync(Base::Model* model, const Base::ResyncMsg& msg);
-    };
-
-  private:
-    DateSelectPopup* popup;
-
   private:
     void OpenPopup();
 
@@ -57,7 +36,8 @@ namespace Lum {
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
 
-    static DateSelect* Create(Base::Model* model=NULL, bool horizontalFlex=false, bool verticalFlex=false);
+    static DateSelect* Create(Base::Model* model=NULL,
+                              bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
