@@ -20,6 +20,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Boolean.h>
 #include <Lum/Model/Dir.h>
@@ -28,14 +30,13 @@
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Dialog.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
 
 namespace Lum {
   namespace Dlg {
 
-    class LUMAPI File : public Dialog
+    class LUMAPI File : public ActionDialog
     {
     public:
       class LUMAPI Options : public Base::Referencable
@@ -67,23 +68,23 @@ namespace Lum {
       typedef Base::Reference<Options> OptionsRef;
 
     private:
-      Model::DirRef       dirList;
-      Model::PathRef      path;
-      Model::StringRef    full;
-      Model::SizeTRef     filter;
-      Model::BooleanRef   showHidden;
-      Model::ActionRef    okAction;
-      Model::ActionRef    reloadAction;
-      Model::ActionRef    parentAction;
-      Model::ActionRef    fullAction;
-      Model::ActionRef    selectionAction;
-      Model::ActionRef    doubleClickAction;
-      Model::ActionRef    locationsAction;
-      String              *fullStr;
-      Button              *locations;
-      Table               *table;
-      bool                result;
-      OptionsRef          options;
+      Model::DirRef                 dirList;
+      Model::PathRef                path;
+      Model::StringRef              full;
+      Model::SizeTRef               filter;
+      Model::BooleanRef             showHidden;
+      Model::ActionRef              okAction;
+      Model::ActionRef              reloadAction;
+      Model::ActionRef              parentAction;
+      Model::ActionRef              fullAction;
+      Model::ActionRef              doubleClickAction;
+      Model::ActionRef              locationsAction;
+      Model::SingleLineSelectionRef selection;
+      String                        *fullStr;
+      Button                        *locations;
+      Table                         *table;
+      bool                          result;
+      OptionsRef                    options;
 
     private:
       void SetPath(const std::wstring& path);
@@ -104,7 +105,8 @@ namespace Lum {
       File();
       virtual ~File();
 
-      void PreInit();
+      Lum::Object* GetContent();
+      void GetActions(std::vector<ActionInfo>& actions);
 
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
 
