@@ -48,9 +48,6 @@ namespace Lum {
     int                  grabStart;  /** The start of the column currently grabbed */
     size_t               grabColumn; /** The column that gets grabbed */
 
-  private:
-    void DrawHeader(OS::DrawInfo* draw, size_t start);
-
   public:
     Header();
     virtual ~Header();
@@ -63,6 +60,9 @@ namespace Lum {
 
     bool SetModel(Base::Model* model);
 
+    void Layout();
+    void PreDrawChilds(OS::DrawInfo* draw);
+    void PostDrawChilds(OS::DrawInfo* draw);
     void Draw(int x, int y, size_t w, size_t h);
 
     bool HandleMouseEvent(const OS::MouseEvent& event);
