@@ -30,7 +30,7 @@ namespace Lum {
   namespace Model {
 
     template <class V>
-    class Simple : public Base::Model
+    class LUMAPI Simple : public Base::Model
     {
     private:
       class Value
@@ -63,7 +63,7 @@ namespace Lum {
       void Set(const V& value);
       const V& Get() const;
 
-      void operator=(const V& value);
+      const V& operator=(const V& value);
       operator V() const;
     };
 
@@ -194,9 +194,11 @@ namespace Lum {
     }
 
     template <class V>
-    void Simple<V>::operator=(const V& value)
+    const V& Simple<V>::operator=(const V& value)
     {
       Set(value);
+
+      return value;
     }
 
     template <class V>
