@@ -52,14 +52,17 @@ namespace Lum {
     Object* GetEntry(size_t pos) const;
     size_t GetSize() const;
 
-    void Append(Object* object);
-    void Remove(size_t pos);
-    void Remove(Object* object);
+    Multi* Append(Object* object);
+    Multi* Remove(size_t pos);
+    Multi* Remove(Object* object);
 
     void ShowPrevious();
     void ShowNext();
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static Multi* Create(Base::Model* index=NULL,
+                         bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
