@@ -22,6 +22,7 @@
 
 #include <map>
 
+#include <Lum/OS/Behaviour.h>
 #include <Lum/OS/Display.h>
 #include <Lum/OS/Driver.h>
 #include <Lum/OS/Theme.h>
@@ -58,6 +59,7 @@ namespace Lum {
         Size                             size;
 
         Color                            color[colorCount];
+        Behaviour                        *behaviour;
         Theme                            *theme;
 
         mutable std::map<size_t,FontRef> propFonts;
@@ -102,6 +104,8 @@ namespace Lum {
         size_t GetArgCount() const;
         std::wstring GetArg(size_t pos) const;
 
+        Behaviour* GetBehaviour() const;
+
         std::wstring GetThemePath() const;
         std::wstring GetThemeName() const;
         Theme* GetTheme() const;
