@@ -26,6 +26,7 @@
 
 #include <Lum/Base/Model.h>
 
+#include <Lum/Def/Boolean.h>
 #include <Lum/Def/Menu.h>
 #include <Lum/Def/MultiView.h>
 #include <Lum/Def/OneOfMany.h>
@@ -71,6 +72,18 @@ namespace Lum {
       Behaviour();
       virtual ~Behaviour();
 
+      /**
+        If true, the first focusable object in a window will be automatically
+        focused.
+        */
+      virtual bool FocusObjectOnWindowFocusIn() const = 0;
+
+      /**
+        If true, scroll knob can be grabed to change the position in a scrolled
+        view.
+        */
+      virtual bool ScrollKnobActive() const = 0;
+
       /**
         @name Menu
         Using system specific menu implementation
@@ -97,6 +110,11 @@ namespace Lum {
       virtual Lum::Object* GetOneOfManyControl(Def::OneOfMany& def,
                                                bool horizFlex,
                                                bool vertFlex) const = 0;
+
+      virtual Lum::Object* GetBooleanControl(Def::Boolean& def) const = 0;
+      virtual Lum::Object* GetBooleanControl(Def::Boolean& def,
+                                             bool horizFlex,
+                                             bool vertFlex) const = 0;
       /**
         @name Behaviours
         Choosing between different behaviours.
