@@ -64,11 +64,21 @@ namespace Lum {
     public:
       PlainFill(Color color);
 
-      virtual void Draw(DrawInfo* draw,
-                        int xOff, int yOff, size_t width, size_t height,
-                        int x, int y, size_t w, size_t h);
+      void Draw(DrawInfo* draw,
+                int xOff, int yOff, size_t width, size_t height,
+                int x, int y, size_t w, size_t h);
     };
 
+    /**
+      Draw background using a plain color.
+    */
+    class LUMAPI EmptyFill : public Fill
+    {
+    public:
+      void Draw(DrawInfo* draw,
+                int xOff, int yOff, size_t width, size_t height,
+                int x, int y, size_t w, size_t h);
+    };
 
 #if defined(LUM_INSTANTIATE_TEMPLATES)
     LUM_EXPTEMPL template class LUMAPI Lum::Base::Reference<Fill>;
