@@ -29,10 +29,14 @@ namespace Lum {
       class Behaviour : public OS::Base::DefaultBehaviour
       {
       public:
+        bool FocusObjectOnWindowFocusIn() const;
+        bool ScrollKnobActive() const;
+
         CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
         void ApplyMultiViewDlg(Dialog* dialog,
                                const Def::MultiView& multiView) const;
         Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
+        Lum::Object* GetBooleanControl(Def::Boolean& def) const;
       };
 
     }
