@@ -24,6 +24,8 @@
 
 #include <Lum/Base/Model.h>
 
+#include <Lum/Model/Action.h>
+
 namespace Lum {
   namespace OS {
     namespace Manager {
@@ -32,12 +34,22 @@ namespace Lum {
       */
       class LUMAPI DisplayManager : public Lum::Base::MsgObject
       {
+      public:
+        enum DisplayState
+        {
+          DisplayStateUnknown,
+          DisplayStateOff,
+          DisplayStateOn
+        };
+
       protected:
         DisplayManager();
 
       public:
         virtual ~DisplayManager();
 
+        virtual DisplayState GetDisplayState() const = 0;
+        virtual Model::Action* GetDisplayStateChangeAction() const = 0;
         virtual bool AllowScreenBlanking(bool blankable) = 0;
       };
     }
