@@ -92,6 +92,7 @@ namespace Lum {
 
     class LUMAPI Mutex
     {
+    private:
 #if defined(__WIN32__) || defined(WIN32)
       CRITICAL_SECTION handle;
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
@@ -104,12 +105,19 @@ namespace Lum {
       void Lock();
       void Unlock();
 
+#if defined(__WIN32__) || defined(WIN32)
+      CRITICAL_SECTION GetHandle() const;
+#elif defined(ILLUMINATION_THREAD_PTHREAD)
+      pthread_mutex_t*  GetHandle();
+#endif
+
     private:
       Mutex(const Mutex& other);
     };
 
     class LUMAPI TryMutex
     {
+    private:
 #if defined(__WIN32__) || defined(WIN32)
       CRITICAL_SECTION handle;
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
@@ -129,6 +137,7 @@ namespace Lum {
 
     class LUMAPI RWMutex
     {
+    private:
 #if defined(__WIN32__) || defined(WIN32)
       CRITICAL_SECTION handle;
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
@@ -206,6 +215,24 @@ namespace Lum {
       }
     };
 
+    class LUMAPI Condition
+    {
+    private:
+#if defined(__WIN32__) || defined(WIN32)
+#elif defined(ILLUMINATION_THREAD_PTHREAD)
+      pthread_cond_t handle;
+#endif
+    public:
+      Condition();
+      virtual ~Condition();
+
+      void Signal();
+      void Broadcast();
+      void Wait(Mutex& mutex);
+
+    private:
+      Condition(const Condition& other);
+    };
 
     typedef Guard<Mutex>    MutexGuard;
     typedef Guard<RWMutex>  RWMutexReadGuard;
