@@ -51,7 +51,9 @@ namespace Lum {
         bool GetAlpha() const;
         unsigned long GetDrawCap() const;
 
-        void Draw(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void Draw(OS::DrawInfo *draw, int x, int y);
+        void DrawScaled(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
+        void DrawStretched(OS::DrawInfo *draw, int x, int y, size_t w, size_t h);
       };
 
       class Fill : public OS::Fill
