@@ -50,12 +50,6 @@ namespace Lum {
 
       private:
         Display     *display;
-        MouseEvent  oldButton;
-        MouseEvent  lastButton;
-        MouseEvent  thisButton;
-        Time        oldPress;
-        Time        lastPress;
-        Time        thisPress;
         long        balloonId;
         ::Window    window;
         bool        fullScreen;
@@ -69,6 +63,7 @@ namespace Lum {
 
       public:
         Window(OS::Display* display);
+        ~Window();
 
         // setter
         void SetTitle(const std::wstring& name);
@@ -108,15 +103,12 @@ namespace Lum {
 
         bool SendBalloonMessage(const std::wstring& text,unsigned long timeout);
 
-        bool IsDoubleClicked() const;
-        bool IsTrippleClicked() const;
-
         bool SetFullScreen();
         bool LeaveFullScreen();
         bool IsFullScreen() const;
 
         bool SetOpacity(double opacity);
-        
+
         void SetCustomWindowType(Atom type);
       };
     }
