@@ -124,6 +124,7 @@ namespace Lum {
     bool             readOnly;         //! The control is read only
     bool             cursorVisible;    //! The cursor is currently visible (=> cursor blinking)
     bool             showClearButton;  //! Show a clear button as part of control
+    Lum::OS::ImageRef clearImage;      //! Image to be shown as clear button
     Mode             mode;             //! Draw mode to be used for drawing the text
     Model::ActionRef blinkAction;      //! Timer action for triggering cursor blinking
 
@@ -164,6 +165,7 @@ namespace Lum {
     void EvaluateMarkAllActionRights();
 
     void OpenInputHelper();
+    bool GetShowClearButton() const;
 
   public:
     String();
@@ -172,6 +174,12 @@ namespace Lum {
     bool HasBaseline() const;
     size_t GetBaseline() const;
 
+    bool HasImplicitLabel() const;
+
+    bool IsInEditingArea(OS::MouseEvent* event) const;
+
+    IMHandler* GetIMHandler();
+
     // Setter
     bool SetModel(Base::Model* model);
 
@@ -228,6 +236,7 @@ namespace Lum {
     void ActionDelete();
 
     void SetCursorPos(size_t pos);
+    size_t GetCursorPos() const;
 
     bool CanExecuteAction(const Base::Datatype& type,
                           Base::DataExchangeObject::ExchangeAction action) const;
