@@ -26,6 +26,8 @@
 
 #include <Lum/Model/Integer.h>
 
+#include <Lum/FrameGroup.h>
+#include <Lum/Multi.h>
 #include <Lum/Object.h>
 
 namespace Lum {
@@ -33,23 +35,14 @@ namespace Lum {
   class LUMAPI Tab : public Control
   {
   private:
-    class Entry
-    {
-    public:
-      Object *rider;
-      Object *object;
-    };
+    Model::SizeTRef  model;       //! numeric model defining the currently visible entry.
+    size_t           mw;          //! width of single tab rider
+    size_t           mh;          //! height of single tab rider
+    Object           *lastDrawn;  //! At that time visible object during last draw
+    FrameGroup       *frameGroup; //! FrameGroup object containing the Multi object
+    Multi            *multi;      //! Multi object, containing list of objects
 
-  private:
-    Model::SizeTRef  model;      //! numeric model defining the currently visible entry.
-    size_t           mw;         //! width of single tab rider
-    size_t           mh;         //! height of single tab rider
-    Object           *lastDrawn; //! At that time visible object during last draw
-
-    std::list<Entry> list;       //! list of embeded objects
-
-  private:
-    Object* GetObject() const;
+    std::list<Object*> list;       //! list of embeded objects
 
   public:
     Tab();
@@ -57,8 +50,8 @@ namespace Lum {
 
     bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
-    void Add(Object* label, Object* object);
-    void Add(const std::wstring& label, Object* object);
+    Tab* Add(Object* label, Object* object);
+    Tab* Add(const std::wstring& label, Object* object);
 
     void ActivatePreviousTab();
     void ActivateNextTab();
@@ -69,9 +62,10 @@ namespace Lum {
 
     void Layout();
     void Draw(int x, int y, size_t w, size_t h);
-    void Hide();
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static Tab* Create(bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
