@@ -22,6 +22,7 @@
 
 #include <Lum/Base/Size.h>
 
+#include <Lum/Menu.h>
 #include <Lum/Object.h>
 
 namespace Lum {
@@ -29,17 +30,17 @@ namespace Lum {
   class LUMAPI WindowGroup : public Group
   {
   private:
-    Object *men;
-    Object *main;
-    Object *tool;
-    Object *status;
-    bool   mainSeamless;
+    MenuStrip *men;
+    Object    *main;
+    Object    *tool;
+    Object    *status;
+    bool      mainSeamless;
 
   public:
     WindowGroup();
     virtual ~WindowGroup();
 
-    void SetMenuStrip(Object* object);
+    void SetMenuStrip(MenuStrip* menuStrip);
     void SetToolbar(Object* object);
     void SetMain(Object* object, bool seamless=false);
     void SetStatusLine(Object* object);
