@@ -19,6 +19,8 @@
 
 #include <Lum/Array.h>
 
+#include <Lum/Space.h>
+
 namespace Lum {
 
   Array::Array()
@@ -55,6 +57,13 @@ namespace Lum {
     }
   }
 
+  Array* Array::AddEmpty()
+  {
+    Add(new VSpace());
+
+    return this;
+  }
+
   void Array::CalcSize()
   {
     std::list<Object*>::iterator iter;
