@@ -27,8 +27,10 @@
   #include <unistd.h>
 #endif
 
+#include <cmath>
 #include <cwchar>
 #include <cstring>
+#include <iomanip>
 #include <memory>
 #include <sstream>
 
@@ -37,7 +39,7 @@
 #if defined(HAVE_ICONV)
   #include <Lum/Private/IconvHelper.h>
 #endif
-
+#include <iostream>
 #if defined(EXPLICIT_WSTRING)
 template class std::basic_string<wchar_t, std::char_traits<wchar_t>, std::allocator<wchar_t> >;
 #endif
@@ -178,6 +180,58 @@ namespace Lum {
       }
     }
 
+    std::string ByteSizeToString(double value)
+    {
+      std::stringstream buffer;
+
+      buffer.imbue(std::locale(""));
+      buffer.setf(std::ios::fixed);
+      buffer << std::setprecision(1);
+
+      if (ceil(value)>=1024.0*1024*1024*1024*0.5) {
+        buffer << value/(1024.0*1024*1024*1024) << " TB";
+      }
+      else if (ceil(value)>=1024.0*1024*1024*0.5) {
+        buffer << value/(1024.0*1024*1024) << " GB";
+      }
+      else if (ceil(value)>=1024.0*1024*0.5) {
+        buffer << value/(1024.0*1024) << " MB";
+      }
+      else if (ceil(value)>=1024.0*0.5) {
+        buffer << value/1024.0 << " KB";
+      }
+      else {
+        buffer << value << " Byte";
+      }
+
+      return buffer.str();
+    }
+
+    std::wstring ByteSizeToWString(double value)
+    {
+      return StringToWString(ByteSizeToString(value));
+    }
+
+    std::string TimeSpanToString(size_t seconds)
+    {
+      std::stringstream buffer;
+
+      buffer.imbue(std::locale(""));
+      buffer.setf(std::ios::fixed);
+
+      buffer << seconds/60;
+      buffer << ":";
+      buffer << (seconds%60)/10;
+      buffer << seconds%10;
+
+      return buffer.str();
+    }
+
+    std::wstring TimeSpanToWString(size_t seconds)
+    {
+      return StringToWString(TimeSpanToString(seconds));
+    }
+
     bool MatchWildcardInternal(const std::wstring& pattern, size_t pPos,
                                const std::wstring& string, size_t sPos,
                                bool caseMatch)
