@@ -57,10 +57,10 @@ namespace Lum {
 
     close->SetParent(this);
 
-    if (OS::display->GetTheme()->GetStockImage(OS::Theme::closeStockImage)!=NULL) {
+    if (OS::display->GetTheme()->GetStockImage(OS::Theme::imageClose)!=NULL) {
       Image *image;
       image=new Image();
-      image->SetImage(OS::display->GetTheme()->GetStockImage(OS::Theme::closeStockImage));
+      image->SetImage(OS::display->GetTheme()->GetStockImage(OS::Theme::imageClose));
       close->SetLabel(image);
     }
     else {
