@@ -24,8 +24,27 @@
 namespace Lum {
 
   Boolean::Boolean()
-   : ImageState(OS::Theme::objCheck)
+   : ImageState(OS::display->GetImage(OS::Display::checkImageIndex))
   {
     // no code
   }
+
+  Boolean* Boolean::Create()
+  {
+    Boolean *b;
+
+    b=new Boolean();
+
+    return b;
+  }
+
+  Boolean* Boolean::Create(Base::Model* model)
+  {
+    Boolean *b;
+
+    b=new Boolean();
+    b->SetModel(model);
+
+    return b;
+  }
 }
