@@ -24,12 +24,11 @@
 #include <Lum/String.h>
 
 namespace Lum {
-  static DirNameSelect::Prefs *prefs=new DirNameSelect::Prefs(L"DirNameSelect");
 
   DirNameSelect::DirNameSelect()
   : PopupControl(new String())
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 
   void DirNameSelect::SetDialogTitle(const std::wstring& title)
