@@ -27,7 +27,9 @@
 namespace Lum {
 
   Knob::Knob()
-  : knob(new Image()),offset(0),corr(0),
+  : knob(new Image()),
+    offset(0),
+    corr(0),
     adjustment(NULL),
     incAction(new Model::Action),
     decAction(new Model::Action),
@@ -112,7 +114,7 @@ namespace Lum {
         adjustment->SetTop(adjustment->GetTotal()+corr-adjustment->GetVisible()+1);
       }
       else {
-        adjustment->SetTop(((y-offset-this->y)*adjustment->GetTotal())/(this->height));
+        adjustment->SetTop(((y-offset-this->y)*adjustment->GetTotal())/(this->height)+1);
       }
     }
     else {
@@ -123,7 +125,7 @@ namespace Lum {
         adjustment->SetTop(adjustment->GetTotal()+corr-adjustment->GetVisible()+1);
       }
       else {
-        adjustment->SetTop(((x-offset-this->x)*adjustment->GetTotal())/(this->width));
+        adjustment->SetTop(((x-offset-this->x)*adjustment->GetTotal())/(this->width)+1);
       }
     }
   }
