@@ -19,6 +19,7 @@
 
 #include <Lum/OS/Base/Behaviour.h>
 
+#include <Lum/Boolean.h>
 #include <Lum/Combo.h>
 #include <Lum/Dialog.h>
 #include <Lum/Tab.h>
@@ -35,6 +36,16 @@ namespace Lum {
       {
       }
 
+      bool DefaultBehaviour::FocusObjectOnWindowFocusIn() const
+      {
+        return true;
+      }
+
+      bool DefaultBehaviour::ScrollKnobActive() const
+      {
+        return true;
+      }
+
       OS::Behaviour::CustomMenuHandler* DefaultBehaviour::GetCustomMenuHandler(OS::Window* window) const
       {
         return NULL;
@@ -98,6 +109,32 @@ namespace Lum {
 
         return control;
       }
+
+      Lum::Object* DefaultBehaviour::GetBooleanControl(Def::Boolean& def) const
+      {
+        Boolean *control;
+
+        control=new Boolean();
+        control->SetFlex(true,false);
+        control->SetModel(def.GetBoolean());
+
+        return control;
+      }
+
+      Lum::Object* DefaultBehaviour::GetBooleanControl(Def::Boolean& def,
+                                                       bool horizFlex,
+                                                       bool vertFlex) const
+      {
+        Lum::Object* control;
+
+        control=GetBooleanControl(def);
+
+        if (control!=NULL) {
+          control->SetFlex(horizFlex,vertFlex);
+        }
+
+        return control;
+      }
     }
   }
 }
