@@ -41,6 +41,7 @@ namespace Lum {
       : scrWidth(0),scrHeight(0),workAreaWidth(0),workAreaHeight(0),
         multiClickTime(200),
         appName(L""),
+        behaviour(NULL),
         theme(NULL),
         eventLoop(NULL)
       {
@@ -94,6 +95,7 @@ namespace Lum {
         propFont=NULL;
         fixedFont=NULL;
 
+        delete behaviour;
         delete theme;
       }
 
@@ -155,6 +157,11 @@ namespace Lum {
         return path.GetPath();
       }
 
+      Behaviour* Display::GetBehaviour() const
+      {
+        return behaviour;
+      }
+
       Theme* Display::GetTheme() const
       {
         return theme;
