@@ -21,6 +21,7 @@
 
 #include <Lum/OS/Driver.h>
 #include <Lum/OS/Theme.h>
+#include <Lum/OS/Manager/Repository.h>
 
 namespace Lum {
   namespace OS {
@@ -708,8 +709,14 @@ namespace Lum {
       {
         OS::Window::RedrawMsg msg;
 
+        // Somebody has likely called Object::Redraw() during a draw => We ignore this...
         if (!redrawAction->IsInactive()) {
-          // Somebody has likely called Object::Redraw() during a draw => We ignore this.
+          return;
+        }
+
+        // We do not redraw anything if the display is off...
+        if (Manager::repository->GetDisplayManager()!=NULL &&
+            Manager::repository->GetDisplayManager()->GetDisplayState()==OS::Manager::DisplayManager::DisplayStateOff) {
           return;
         }
 
