@@ -62,11 +62,6 @@ namespace Lum {
       std::wstring home;
       */
 
-    bool Display::Timer::operator<(const Timer& other) const
-    {
-      return time<other.time;
-    }
-
     struct ColorEntry
     {
       Display::ColorIndex index;
