@@ -270,13 +270,16 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        oldPress(0),lastPress(0),thisPress(0),
         drawn(false),queueFocus(false),
         window(0)
       {
         // no code
       }
 
+      Window::~Window()
+      {
+        // no code
+      }
 
       /**
         Grabs the mouse cursor and keyboard.
@@ -585,29 +588,14 @@ namespace Lum {
         return true;
       }
 
-      bool Window::IsDoubleClicked() const
-      {
-        return (lastButton.type==thisButton.type)
-          && (lastButton.qualifier==thisButton.qualifier)
-          && (abs(lastButton.x-thisButton.x)<5)
-          && (abs(lastButton.y-thisButton.y)<5)
-          && (thisPress-lastPress<=display->GetMultiClickTime());
-        return false;
-      }
-
-      bool Window::IsTrippleClicked() const
-      {
-        return false;
-      }
-
       LRESULT Window::MessageHandler(HWND wnd,UINT msg, WPARAM wParam, LPARAM lParam)
       {
-        HDC         dc;
-        PAINTSTRUCT ps;
-        OS::Event   *event;
-        MSG         winMsg;
-        WINDOWPOS   *pos;
-        MINMAXINFO  *mmInfo;
+        HDC          dc;
+        PAINTSTRUCT  ps;
+        OS::EventRef event;
+        MSG          winMsg;
+        WINDOWPOS    *pos;
+        MINMAXINFO   *mmInfo;
 
         switch (msg) {
         case WM_CLOSE:
@@ -667,17 +655,7 @@ namespace Lum {
           winMsg.wParam=wParam;
           winMsg.message=msg;
           event=GetEvent(this,winMsg);
-          if (event!=NULL) {
-
-            if (dynamic_cast<MouseEvent*>(event)!=NULL && dynamic_cast<MouseEvent*>(event)->type==MouseEvent::down) {
-              oldButton=lastButton;
-              oldPress=lastPress;
-              lastButton=thisButton;
-              lastPress=thisPress;
-              thisButton=*dynamic_cast<MouseEvent*>(event);
-              thisPress=GetTickCount();
-            }
-
+          if (event.Valid()) {
             do {
               event->reUse=false;
               /* ignore */ HandleEvent(event);
