@@ -1172,7 +1172,7 @@ namespace Lum {
         res=XGetWindowProperty(display,RootWindow(display,scrNum),
                                atoms[netWorkAreaAtom],2,2,false,atoms[cardinalAtom],
                                &atomType,&atomFormat,&atomItems,&atomBytes,&atomProperties);
-        if ((res==Success) && (atomProperties != NULL)) {
+        if (res==Success && atomProperties!=NULL) {
           workAreaWidth=reinterpret_cast<uint32_t*>(atomProperties)[0];
           workAreaHeight=reinterpret_cast<uint32_t*>(atomProperties)[1];
         }
