@@ -21,6 +21,8 @@
 
 #include <Lum/Base/Util.h>
 
+#include <Lum/Space.h>
+
 namespace Lum {
 
   Panel::Panel()
@@ -28,6 +30,25 @@ namespace Lum {
     // no code
   }
 
+  Panel* Panel::Add(Lum::Object* object)
+  {
+    List::Add(object);
+
+    return this;
+  }
+
+  HPanel::HPanel()
+  {
+    // no code
+  }
+
+  HPanel* HPanel::AddSpace(bool flex)
+  {
+    Add(new HSpace(flex));
+
+    return this;
+  }
+
   void HPanel::CalcSize()
   {
     std::list<Object*>::iterator iter;
@@ -53,6 +74,13 @@ namespace Lum {
     Panel::CalcSize();
   }
 
+  VPanel* VPanel::AddSpace(bool flex)
+  {
+    Add(new VSpace(flex));
+
+    return this;
+  }
+
   void VPanel::CalcSize()
   {
     std::list<Object*>::iterator iter;
@@ -141,6 +169,11 @@ namespace Lum {
     Panel::Layout();
   }
 
+  VPanel::VPanel()
+  {
+    // no code
+  }
+
   void VPanel::Layout()
   {
     std::list<Object*>::iterator iter;
@@ -204,4 +237,24 @@ namespace Lum {
 
     Panel::Layout();
   }
+
+  HPanel* HPanel::Create(bool horizontalFlex, bool verticalFlex)
+  {
+    HPanel *p;
+
+    p=new HPanel();
+    p->SetFlex(horizontalFlex,verticalFlex);
+
+    return p;
+  }
+
+  VPanel* VPanel::Create(bool horizontalFlex, bool verticalFlex)
+  {
+    VPanel *p;
+
+    p=new VPanel();
+    p->SetFlex(horizontalFlex,verticalFlex);
+
+    return p;
+  }
 }
