@@ -37,14 +37,13 @@ namespace Lum {
     Object::CalcSize();
   }
 
-  void Placeholder::Draw(int x, int y, size_t w, size_t h)
+  Placeholder* Placeholder::Create(bool horizontalFlex, bool verticalFlex)
   {
-    Object::Draw(x,y,w,h);
+    Placeholder *o;
 
-    if (!OIntersect(x,y,w,h)) {
-      return;
-    }
+    o=new Placeholder();
+    o->SetFlex(horizontalFlex,verticalFlex);
 
-    DrawBackground(x,y,w,h);
+    return o;
   }
 }
