@@ -61,7 +61,12 @@ namespace Lum {
     delete this->main;
     this->main=main;
 
-    this->seamless=seamless;
+    if (OS::display->GetTheme()->PopupsAreDialogs()) {
+      this->seamless=false;
+    }
+    else {
+      this->seamless=seamless;
+    }
     this->border=border;
   }
 
@@ -165,6 +170,16 @@ namespace Lum {
     Window::SetMain(container);
   }
 
+  bool Popup::Open(bool activate)
+  {
+    // Popups should recalculate their size on each Open() call
+    if (!IsOpen() && GetWindow()->IsInited()) {
+      ReinitWindow();
+    }
+
+    return Window::Open(activate);
+  }
+
   void Popup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
     if (model==GetWindow()->GetClosedAction() &&
