@@ -120,17 +120,31 @@ namespace Lum {
     }
     panel->SetParent(this);
 
-    panel->Add(CreateButton(vert,true));
-    if (OS::display->GetTheme()->GetScrollKnobMode()==OS::Theme::scrollKnobModeDouble) {
+    switch (OS::display->GetTheme()->GetScrollKnobMode()) {
+      case OS::Theme::scrollKnobModeSingle:
+      panel->Add(CreateButton(vert,true));
+      break;
+      case OS::Theme::scrollKnobModeDouble:
+      panel->Add(CreateButton(vert,true));
       panel->Add(CreateButton(vert,false));
+      break;
+      case OS::Theme::scrollKnobModeNone:
+      break;
     }
 
     panel->Add(knob);
 
-    if (OS::display->GetTheme()->GetScrollKnobMode()==OS::Theme::scrollKnobModeDouble) {
+    switch (OS::display->GetTheme()->GetScrollKnobMode()) {
+      case OS::Theme::scrollKnobModeSingle:
+      panel->Add(CreateButton(vert,false));
+      break;
+      case OS::Theme::scrollKnobModeDouble:
       panel->Add(CreateButton(vert,true));
+      panel->Add(CreateButton(vert,false));
+      break;
+      case OS::Theme::scrollKnobModeNone:
+      break;
     }
-    panel->Add(CreateButton(vert,false));
 
     panel->CalcSize();
 
