@@ -141,7 +141,7 @@ namespace Lum {
   {
     List::Draw(x,y,w,h); /* We must call Draw of our superclass */
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
