@@ -30,6 +30,77 @@
 
 namespace Lum {
 
+  class StringIMHandler : public IMHandler
+  {
+  private:
+    String* control;
+
+  public:
+    void SetControl(String* control)
+    {
+      this->control=control;
+    }
+
+    void GetData(std::wstring& data,
+                 size_t& cursorOffset)
+    {
+      assert(control!=NULL);
+
+      data=L"";
+      cursorOffset=0;
+
+      Model::StringRef model=dynamic_cast<Model::String*>(control->GetModel());
+
+      if (!model.Valid() ||
+          model->IsNull() ||
+          !model->IsEnabled()) {
+        return;
+      }
+
+      data=model->Get();
+      cursorOffset=control->GetCursorPos();
+    }
+
+    void SetData(const std::wstring& data)
+    {
+      assert(control!=NULL);
+
+      Model::StringRef model=dynamic_cast<Model::String*>(control->GetModel());
+
+      if (!model.Valid() ||
+          model->IsNull() ||
+          !model->IsEnabled()) {
+        return;
+      }
+
+      model->Set(data);
+    }
+
+    void SetCursorOffset(size_t cursorOffset)
+    {
+      assert(control!=NULL);
+
+      Model::StringRef model=dynamic_cast<Model::String*>(control->GetModel());
+
+      if (!model.Valid() ||
+          model->IsNull() ||
+          !model->IsEnabled()) {
+        return;
+      }
+
+      control->SetCursorPos(cursorOffset);
+    }
+
+    bool IsInEditingArea(OS::MouseEvent* event) const
+    {
+      assert(control!=NULL);
+
+      return control->IsInEditingArea(event);
+    }
+  };
+
+  static StringIMHandler *imHandler=NULL;
+
   static ControllerRef controller(new String::Controller());
 
   String::Controller::Controller()
@@ -72,65 +143,57 @@ namespace Lum {
     switch (action) {
     case actionCut:
       string->ActionCut();
-      break;
+      return true;
     case actionCopy:
       string->ActionCopy();
-      break;
+      return true;
     case actionPaste:
       string->ActionPaste();
-      break;
+      return true;
     case actionSelectAll:
       string->ActionSelectAll();
-      break;
+      return true;
     case actionReturn:
-      if (!string->ActionReturn()) {
-        return false;
-      }
-      break;
+      return string->ActionReturn();
     case actionEscape:
-      if (!string->ActionEscape()) {
-        return false;
-      }
-      break;
+      return string->ActionEscape();
     case actionCursorUp:
-      string->ActionCursorUp();
-      break;
+      return string->ActionCursorUp();
     case actionCursorDown:
-      string->ActionCursorDown();
-      break;
+      return string->ActionCursorDown();
     case actionSelectLeft:
       string->ActionSelectLeft();
       break;
     case actionCursorLeft:
       string->ActionCursorLeft();
-      break;
+      return true;
     case actionSelectRight:
       string->ActionSelectRight();
-      break;
+      return true;
     case actionCursorRight:
       string->ActionCursorRight();
-      break;
+      return true;
     case actionSelectStart:
       string->ActionSelectStart();
-      break;
+      return true;
     case actionCursorStart:
       string->ActionCursorStart();
-      break;
+      return true;
     case actionSelectEnd:
       string->ActionSelectEnd();
-      break;
+      return true;
     case actionCursorEnd:
       string->ActionCursorEnd();
-      break;
+      return true;
     case actionBackspace:
       string->ActionBackspace();
-      break;
+      return true;
     case actionDelete:
       string->ActionDelete();
-      break;
+      return true;
     }
 
-    return true;
+    return false;
   }
 
   String::String()
@@ -144,6 +207,7 @@ namespace Lum {
     readOnly(false),
     cursorVisible(false),
     showClearButton(false),
+    clearImage(OS::display->GetTheme()->GetStockImage(OS::Theme::imageClear)),
     mode(normal),
     blinkAction(new Model::Action),
     cutAction(new Model::Action),
@@ -195,6 +259,44 @@ namespace Lum {
     return GetTopBorder()+(height-font->height) / 2 + font->ascent;
   }
 
+  bool String::IsInEditingArea(OS::MouseEvent* event) const
+  {
+    if (!PointIsIn(*event)) {
+      return false;
+    }
+
+    if (showClearButton) {
+      size_t imageWidth=clearImage->GetWidth();
+      size_t imageHeight=clearImage->GetHeight();
+
+      if (imageHeight>height) {
+        imageWidth=(imageWidth*height)/imageHeight;
+      }
+
+      if (event->x>=GetX()+GetWidth()-1-imageWidth) {
+        return false;
+      }
+    }
+
+    return true;
+  }
+
+  bool String::HasImplicitLabel() const
+  {
+    return !label.empty();
+  }
+
+  IMHandler* String::GetIMHandler()
+  {
+    if (imHandler==NULL) {
+      imHandler=new StringIMHandler();
+    }
+
+    imHandler->SetControl(this);
+
+    return imHandler;
+  }
+
   bool String::SetModel(Base::Model* model)
   {
     this->model=dynamic_cast<Model::String*>(model);
@@ -293,6 +395,17 @@ namespace Lum {
     return this;
   }
 
+  bool String::GetShowClearButton() const
+  {
+    if (showClearButton) {
+
+      return clearImage.Valid();
+    }
+    else {
+      return false;
+    }
+  }
+
   Model::Action* String::GetCursorUpAction() const
   {
     return cursorUpAction.Get();
@@ -919,7 +1032,7 @@ namespace Lum {
     /* value to be printed */
     string=GetValue();
 
-    if (string.size()==0 &&
+    if (string.empty() &&
         !draw->focused &&
         model.Valid() &&
         model->IsEnabled()) {
@@ -937,8 +1050,15 @@ namespace Lum {
     xPos=this->x;
     fieldWidth=width;
 
-    if (showClearButton) {
-      fieldWidth-=font->height;
+    if (GetShowClearButton()) {
+      size_t imageWidth=clearImage->GetWidth();
+      size_t imageHeight=clearImage->GetHeight();
+
+      if (imageHeight>height) {
+        imageWidth=(imageWidth*height)/imageHeight;
+      }
+
+      fieldWidth-=imageWidth;
     }
 
     /* Calculate starting pos depending on alignment */
@@ -1087,7 +1207,7 @@ namespace Lum {
         draw->PushForeground(OS::Display::fillColor);
         draw->FillRectangle(cursorPos,yOff,1,font->height);
         draw->PopForeground();
-        draw->PushFont(OS::display->GetFont());
+        draw->PushFont(font);
         draw->PushForeground(OS::Display::fillTextColor);
         draw->DrawString(cursorPos,yOff,string.substr(cursor,1));
         draw->PopForeground();
@@ -1095,20 +1215,24 @@ namespace Lum {
       }
       else {
         draw->PushForeground(OS::Display::editTextColor);
-        draw->FillRectangle(cursorPos,yOff,1,font->height);
+        draw->FillRectangle(cursorPos,yOff,
+                            OS::display->GetTheme()->GetCursorWidth(font),font->height);
         draw->PopForeground();
       }
     }
 
-    if (showClearButton) {
-      draw->PushForeground(OS::Display::fillColor);
-      draw->PushPen(5);
+    if (GetShowClearButton()) {
+      size_t imageWidth=clearImage->GetWidth();
+      size_t imageHeight=clearImage->GetHeight();
 
-      draw->DrawLine(this->x+fieldWidth,yOff,this->x+fieldWidth+font->height,yOff+font->height);
-      draw->DrawLine(this->x+fieldWidth+font->height,yOff,this->x+fieldWidth,yOff+font->height);
-
-      draw->PopPen();
-      draw->PopForeground();
+      if (imageHeight>height) {
+        imageWidth=(imageWidth*height)/imageHeight;
+        imageHeight=height;
+      }
+      clearImage->DrawScaled(draw,
+                             this->x+fieldWidth,
+                             this->y+((int)height-(int)imageHeight)/2,
+                             imageWidth,imageHeight);
     }
 
     draw->PopClip();
@@ -1131,6 +1255,11 @@ namespace Lum {
     }
   }
 
+  size_t String::GetCursorPos() const
+  {
+    return cursor;
+  }
+
   /**
     Clears the current selection.
   */
@@ -1158,13 +1287,17 @@ namespace Lum {
       return false;
     }
 
-    if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.button==OS::MouseEvent::button1) {
+    if (event.type==OS::MouseEvent::down &&
+        PointIsIn(event) &&
+        event.button==OS::MouseEvent::button1) {
       OS::Window* window=GetWindow();
 
-      if (showClearButton && event.x>=this->x+(int)(this->width-1-font->height)) {
+      if (GetShowClearButton() &&
+          event.x>=this->x+(int)(this->width-1-OS::display->GetTheme()->GetStockImage(OS::Theme::imageClear)->GetWidth())) {
         ActionEraseAll();
       }
-      else  if (window->IsDoubleClicked()) {
+      else if (window->IsDoubleClicked() &&
+               PointIsIn(window->GetLastButtonClickEvent())) {
         SelectAll();
         Redraw();
       }
@@ -1175,9 +1308,13 @@ namespace Lum {
         ClearSelection();
         Redraw();
       }
+
       return true;
     }
-    else if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.qualifier==0 && event.button==OS::MouseEvent::button2) {
+    else if (event.type==OS::MouseEvent::down &&
+             PointIsIn(event) &&
+             event.qualifier==0 &&
+             event.button==OS::MouseEvent::button2) {
       selected=true;
       cursor=GetCursorPos(event.x);
       TriggerCursorBlink();
@@ -1188,7 +1325,9 @@ namespace Lum {
 
       return true;
     }
-    else if (event.IsGrabEnd() && event.type==OS::MouseEvent::up && event.button==OS::MouseEvent::button1) {
+    else if (event.IsGrabEnd() &&
+             event.type==OS::MouseEvent::up &&
+             event.button==OS::MouseEvent::button1) {
       if (!window->IsDoubleClicked()) {
         size_t help=GetCursorPos(event.x);
 
@@ -1205,7 +1344,9 @@ namespace Lum {
         OpenInputHelper();
       }
     }
-    else if (event.type==OS::MouseEvent::move && event.IsGrabed() && event.qualifier==OS::qualifierButton1) {
+    else if (event.type==OS::MouseEvent::move &&
+             event.IsGrabed() &&
+             event.qualifier==OS::qualifierButton1) {
       size_t help=GetCursorPos(event.x);
 
       if (help>cursor) {
@@ -1235,6 +1376,10 @@ namespace Lum {
       return false;
     case OS::keyLeftTab:
       return false;
+    case OS::keyUp:
+      return false;
+    case OS::keyDown:
+      return false;
     case OS::keyReturn:
       break;
     case OS::keyEscape:
@@ -1247,7 +1392,9 @@ namespace Lum {
         event.GetName(name);
         qualifier=event.qualifier & ~(OS::qualifierShiftLeft|OS::qualifierShiftRight|OS::qualifierShift|OS::qualifierCapsLock);
 
-        if (!event.text.empty() && !(name==event.text && qualifier!=0) && event.text[0]>=32) {
+        if (!event.text.empty() &&
+            !(name==event.text && qualifier!=0) &&
+            event.text[0]>=32) {
           ActionInsertString(event.text);
           return true;
         }
@@ -1279,9 +1426,8 @@ namespace Lum {
     if (event.type==OS::KeyEvent::down) {
       return HandleKeys(event);
     }
-    else {
-      return false;
-    }
+
+    return false;
   }
 
   void String::RecatchedFocus()
