@@ -65,8 +65,10 @@ namespace Lum {
     this->model=model;
     SetModel(model.Get());
 
-    SetCanFocus(true);
-    RequestFocus();
+    if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+      SetCanFocus(true);
+      RequestFocus();
+    }
 
     image->SetParent(this);
   }
