@@ -187,8 +187,13 @@ namespace Lum {
   */
   void TableView::SetRowHeight(size_t height)
   {
-    rowHeight=std::max(OS::display->GetTheme()->GetMinimalTableRowHeight(),
-                       height);
+    if (selection.Valid()) {
+      rowHeight=std::max(OS::display->GetTheme()->GetMinimalTableRowHeight(),
+                         height);
+    }
+    else {
+      rowHeight=height;
+    }
   }
 
   void TableView::RecalcTableWidth()
