@@ -65,38 +65,40 @@ namespace Lum {
 
   void Time::CalcSize()
   {
-    Label    *label;
-    Slider   *slider;
-    TimeView *view;
+    if (container==NULL) {
+      Label    *label;
+      Slider   *slider;
+      TimeView *view;
 
-    label=new Label();
+      label=new Label();
 
-    view=new Lum::TimeView();
-    view->SetFormat(format);
-    view->SetModel(this->model);
-    label->AddLabel(_l(L"TIME_VALUE",L"Value:"),view);
+      view=new Lum::TimeView();
+      view->SetFormat(format);
+      view->SetModel(this->model);
+      label->AddLabel(_l(L"TIME_VALUE",L"Value:"),view);
 
-    slider=new HSlider();
-    slider->SetFlex(true,false);
-    slider->SetScale(false);
-    slider->SetModel(hour);
-    label->AddLabel(_l(L"TIME_HOUR",L"Hour:"),slider);
-
-    slider=new HSlider();
-    slider->SetFlex(true,false);
-    slider->SetScale(false);
-    slider->SetModel(minute);
-    label->AddLabel(_l(L"TIME_MINUTE",L"Minute:"),slider);
-
-    if (format==Base::timeFormatHMS) {
       slider=new HSlider();
       slider->SetFlex(true,false);
       slider->SetScale(false);
-      slider->SetModel(second);
-      label->AddLabel(_l(L"TIME_SECOND",L"Second:"),slider);
-    }
+      slider->SetModel(hour);
+      label->AddLabel(_l(L"TIME_HOUR",L"Hour:"),slider);
 
-    container=label;
+      slider=new HSlider();
+      slider->SetFlex(true,false);
+      slider->SetScale(false);
+      slider->SetModel(minute);
+      label->AddLabel(_l(L"TIME_MINUTE",L"Minute:"),slider);
+
+      if (format==Base::timeFormatHMS) {
+        slider=new HSlider();
+        slider->SetFlex(true,false);
+        slider->SetScale(false);
+        slider->SetModel(second);
+        label->AddLabel(_l(L"TIME_SECOND",L"Second:"),slider);
+      }
+
+      container=label;
+    }
 
     ControlComponent::CalcSize();
   }
