@@ -100,44 +100,6 @@ namespace Lum {
     }
   }
 
-  void TimeLine::DrawPoint(size_t pos, bool scroll)
-  {
-    int          xo,yo;
-    size_t       wo,ho;
-    OS::DrawInfo *draw;
-
-    draw=GetDrawInfo();
-
-    CalculateBounds(xo,yo,wo,ho);
-
-    if (scroll) {
-      draw->CopyArea(xo+1,yo,wo-1,ho,xo,yo);
-
-      draw->disabled=!state;
-      DrawBackground(xo+wo-1,yo,1,ho);
-      draw->disabled=false;
-    }
-
-    draw->PushClip(xo,yo,wo,ho);
-
-    for (size_t y=0; y<points.size(); y++) {
-      draw->PushForeground(colors[y]);
-
-      if (pos==0) {
-        draw->DrawPoint(xo,yo+TransformY(points[y][0],ho));
-      }
-      else {
-        draw->DrawLine(xo+pos-1,
-                       yo+TransformY(points[y][pos-1],ho),
-                       xo+pos,
-                       yo+TransformY(points[y][pos],ho));
-      }
-      draw->PopForeground();
-    }
-
-    draw->PopClip();
-  }
-
   void TimeLine::CalculateBounds(int &xo, int &yo, size_t &wo, size_t &ho)
   {
     xo=x;
@@ -168,6 +130,16 @@ namespace Lum {
     }
   }
 
+  double TimeLine::GetBottom() const
+  {
+    return bottom;
+  }
+
+  double TimeLine::GetTop() const
+  {
+    return top;
+  }
+
   /**
     The the interval at which horizontal and vertical
     scaling lines will be displayed.
@@ -238,10 +210,6 @@ namespace Lum {
 
     draw->PushClip(x,y,w,h);
 
-    draw->disabled=!state;
-    DrawBackground(x,y,w,h);
-    draw->disabled=false;
-
     CalculateBounds(xo,yo,wo,ho);
 
     draw->PushForeground(OS::display->GetColor(OS::Display::graphScaleColor));
@@ -332,11 +300,43 @@ namespace Lum {
         points[y][nextPos]=this->model->Get(y);
       }
 
-      if (visible) {
-        DrawPoint(nextPos,scroll);
-      }
+      Redraw();
 
       nextPos++;
     }
   }
+
+  TimeLine* TimeLine::Create(bool horizontalFlex, bool verticalFlex)
+  {
+    TimeLine *t;
+
+    t=new TimeLine();
+    t->SetFlex(horizontalFlex,verticalFlex);
+
+    return t;
+  }
+
+  TimeLine* TimeLine::Create(Base::Model* model, bool horizontalFlex, bool verticalFlex)
+  {
+    TimeLine *t;
+
+    t=new TimeLine();
+    t->SetFlex(horizontalFlex,verticalFlex);
+    t->SetModel(model);
+
+    return t;
+  }
+
+  TimeLine* TimeLine::Create(Base::Model* model, double bottom, double top,
+                             bool horizontalFlex, bool verticalFlex)
+  {
+    TimeLine *t;
+
+    t=new TimeLine();
+    t->SetFlex(horizontalFlex,verticalFlex);
+    t->SetModel(model);
+    t->SetRange(bottom,top);
+
+    return t;
+  }
 }
