@@ -165,9 +165,10 @@ namespace Lum {
 
   void View::Layout()
   {
-    object->Resize(width-vScroller->GetOWidth(),
-                   height-hScroller->GetOHeight());
-    object->Layout();
+    hScroller->ResizeWidth(GetOWidth());
+    hScroller->Layout();
+    vScroller->ResizeHeight(GetOHeight());
+    vScroller->Layout();
 
     if (hVisible &&
         (!object->GetHAdjustment()->IsValid() ||
